@@ -1,6 +1,23 @@
 import asyncio,httpx,logging,json
 from .utils import *
 from abstract_apis import get_headers,get_response
+def run_in_event_loop(coro):
+    """
+    Execute a coroutine in the appropriate context.
+    If inside an existing event loop, use `asyncio.create_task`.
+    Otherwise, use `asyncio.run`.
+    """
+    try:
+        loop = asyncio.get_running_loop()
+        if loop.is_running():
+            # Inside an active event loop
+            return asyncio.create_task(coro)
+    except RuntimeError:
+        # No running event loop
+        pass
+
+    # Run in a new event loop
+    return asyncio.run(coro)
 def get_response(obj):
     try:
         return obj.json()
@@ -29,6 +46,7 @@ def get_kwargs_bools(key, bools, **kwargs):
 
 def get_solcatcherSettings(getApi=False, **kwargs):
     bools = {}
+    
     bools, kwargs = get_kwargs_bools(key='solcatcherSettings', bools=bools, **kwargs)
     bools, kwargs = get_kwargs_bools(key='headers', bools=bools, **kwargs)
     headers = bools.get('headers', get_headers())
@@ -98,6 +116,7 @@ async def async_call_solcatcher_py(endpoint, *args, **kwargs):
     return result
 
 async def async_call_solcatcher_db(endpoint, *args, **kwargs):
+    
     kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
     kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(True, **kwargs)
     payload = get_payload(*args, **kwargs)
@@ -175,21 +194,19 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     # If no response after all attempts, return empty or raise an exception
     return []
 
-def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,**kwargs):
-    return call_async_function(async_call_rate_limiter,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs)
+def call_rate_limiter(method, params, url_1_only=True, url_2_only=False, **kwargs):
+    return run_in_event_loop(async_call_rate_limiter(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only, **kwargs))
 
-def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,**kwargs):
-    return call_async_function(async_make_rate_limited_call,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,**kwargs)
+def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False, **kwargs):
+    return run_in_event_loop(async_make_rate_limited_call(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only, **kwargs))
 
-def call_solcatcher_py(endpoint,*args,**kwargs):
-    return call_async_function(async_call_solcatcher_py,endpoint,*args,**kwargs)
-
-def call_solcatcher_ts(endpoint,*args,**kwargs):
-    return call_async_function(async_call_solcatcher_ts,endpoint,*args,**kwargs)
-
-def call_solcatcher_db(endpoint,*args, **kwargs):
-    return call_async_function(async_call_solcatcher_db,endpoint,*args,**kwargs)
+def call_solcatcher_py(endpoint, *args, **kwargs):
+    return run_in_event_loop(async_call_solcatcher_py(endpoint, *args, **kwargs))
 
+def call_solcatcher_ts(endpoint, *args, **kwargs):
+    return run_in_event_loop(async_call_solcatcher_ts(endpoint, *args, **kwargs))
 
+def call_solcatcher_db(endpoint, *args, **kwargs):
+    return run_in_event_loop(async_call_solcatcher_db(endpoint, *args, **kwargs))
 
 
