@@ -1,8 +1,6 @@
 from abstract_solana import *
-from abstract_solana.rpc_utils import * 
 from ..asyncUtils import *
 from abstract_utilities import get_any_value,make_list
-
 def get_result(response):
     try:
         response = response.json()
@@ -34,11 +32,11 @@ def get_transactions(pair_id=None,txn_id=None,signature=None,log_id=None):
     except Exception as e:
         input(e)
 def decodeInstructionData(data):
-    response = asyncio.run(call_solcatcher_ts('decode-instruction-data', string=data))
+    response = call_solcatcher_ts('decode-instruction-data', string=data)
     decodedData = get_result(response)
     return decodedData
 def upsertPairData(pairData):
-    response = asyncio.run(call_solcatcher_ts('upsert-pair-by-id', pairData=pairData))
+    response = call_solcatcher_ts('upsert-pair-by-id', pairData=pairData)
     pair_id = get_result(response)
     return pair_id
 def upsert_txn(txData):
